@@ -23,8 +23,10 @@ class PeripheralControlComputer:
             "SET_BASE_COLOR": 4,
             "SET_TEMP_COLOR": 5,
             "FIRE_LASER": 6,
-            "RESET_AVR_PERIPH": 7,
-            "CHECK_SERVO_CONTROLLER": 8,
+            "SET_LASER_ON": 7,
+            "SET_LASER_OFF": 8,
+            "RESET_AVR_PERIPH": 9,
+            "CHECK_SERVO_CONTROLLER": 10,
         }
 
         self.shutdown: bool = False
@@ -157,6 +159,24 @@ class PeripheralControlComputer:
         logger.debug(f"Setting the laser on: {data}")
         self.ser.write(data)
 
+    def set_laser_on(self) -> None:
+        command = self.commands["SET_LASER_ON"]
+
+        length = 1
+        data = self._construct_payload(command, length)
+
+        logger.debug(f"Setting the laser on: {data}")
+        self.ser.write(data)
+
+    def set_laser_off(self) -> None:
+        command = self.commands["SET_LASER_OFF"]
+
+        length = 1
+        data = self._construct_payload(command, length)
+
+        logger.debug(f"Setting the laser off: {data}")
+        self.ser.write(data)
+
     def reset_avr_peripheral(self) -> None:
         command = self.commands["RESET_AVR_PERIPH"]
 
